@@ -1,7 +1,21 @@
-/*
- * lookup_program.c
+#ident "$Id: lookup_program.c,v 1.2 1997/10/06 21:52:02 hpa Exp $"
+/* ----------------------------------------------------------------------- *
+ *   
+ *  lookup_program.c - module for Linux automount to access an
+ *                     automount map via a query program 
  *
- * Module for Linux automountd to access a automount map via a query program
+ *   Copyright 1997 Transmeta Corporation - All Rights Reserved
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA 02139,
+ *   USA; either version 2 of the License, or (at your option) any later
+ *   version; incorporated herein by reference.
+ *
+ * ----------------------------------------------------------------------- */
+
+/*
+
  */
 
 #include <ctype.h>
@@ -28,13 +42,14 @@
 #define MAPENT_MAX_LEN 4095
 
 struct lookup_context {
-  char *mapname;
+  const char *mapname;
   struct parse_mod *parse;
 };
 
 int lookup_version = AUTOFS_LOOKUP_VERSION; /* Required by protocol */
 
-int lookup_init(char *mapfmt, int argc, char **argv, void **context)
+int lookup_init(const char *mapfmt, int argc, const char * const *argv,
+		void **context)
 {
   struct lookup_context *ctxt;
 
@@ -65,7 +80,8 @@ int lookup_init(char *mapfmt, int argc, char **argv, void **context)
   return !(ctxt->parse = open_parse(mapfmt,MODPREFIX,argc-1,argv+1));
 }
 
-int lookup_mount(char *root, char *name, int name_len, void *context)
+int lookup_mount(const char *root, const char *name, int name_len,
+		 void *context)
 {
   struct lookup_context *ctxt = (struct lookup_context *) context;
   char mapent[MAPENT_MAX_LEN+1], *mapp;
